#
# spec file for package ghc-amazonka-ssm
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name amazonka-ssm
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        1.4.3
Release:        7.12
Summary:        Amazon Simple Systems Management Service SDK
License:        MPL-2.0
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-amazonka-core-devel
BuildRequires:  ghc-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-amazonka-test-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unordered-containers-devel
%endif

%description
Simple Systems Manager (SSM) enables you to remotely manage the configuration
of your Amazon EC2 instance. Using SSM, you can run scripts or commands using
either EC2 Run Command or SSM Config. (SSM Config is currently available only
for Windows instances.) __Run Command__ Run Command provides an on-demand
experience for executing commands. You can use pre-defined Amazon SSM documents
to perform the actions listed later in this section, or you can create your own
documents. With these documents, you can remotely configure your instances by
sending commands using the __Commands__ page in the
<http://console.aws.amazon.com/ec2/ Amazon EC2 console>,
<http://docs.aws.amazon.com/powershell/latest/reference/items/Amazon_Simple_Systems_Management_cmdlets.html
AWS Tools for Windows PowerShell>, or the
<http://docs.aws.amazon.com/cli/latest/reference/ssm/index.html AWS CLI>.
Run Command reports the status of the command execution for each instance
targeted by a command. You can also audit the command execution to understand
who executed commands, when, and what changes were made. By switching between
different SSM documents, you can quickly configure your instances with
different types of commands. To get started with Run Command, verify that your
environment meets the prerequisites for remotely running commands on EC2
instances
(<http://docs.aws.amazon.com/AWSEC2/latest/UserGuide/remote-commands-prereq.html
Linux> or
<http://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/remote-commands-prereq.html
Windows>). __SSM Config__ SSM Config is a lightweight instance configuration
solution. SSM Config is currently only available for Windows instances.
With SSM Config, you can specify a setup configuration for your instances.
SSM Config is similar to EC2 User Data, which is another way of running
one-time scripts or applying settings during instance launch. SSM Config is an
extension of this capability. Using SSM documents, you can specify which
actions the system should perform on your instances, including which
applications to install, which AWS Directory Service directory to join, which
Microsoft PowerShell modules to install, etc. If an instance is missing one or
more of these configurations, the system makes those changes. By default, the
system checks every five minutes to see if there is a new configuration to
apply as defined in a new SSM document. If so, the system updates the instances
accordingly. In this way, you can remotely maintain a consistent configuration
baseline on your instances. SSM Config is available using the AWS CLI or the
AWS Tools for Windows PowerShell. For more information, see
<http://docs.aws.amazon.com/AWSEC2/latest/WindowsGuide/ec2-configuration-manage.html
Managing Windows Instance Configuration>. SSM Config and Run Command include
the following pre-defined documents. Amazon Pre-defined SSM Documents Name
Description Platform AWS-RunShellScript Run shell scripts Linux
AWS-UpdateSSMAgent Update the Amazon SSM agent Linux
AWS-JoinDirectoryServiceDomain Join an AWS Directory Windows
AWS-RunPowerShellScript Run PowerShell commands or scripts Windows
AWS-UpdateEC2Config Update the EC2Config service Windows
AWS-ConfigureWindowsUpdate Configure Windows Update settings Windows
AWS-InstallApplication Install, repair, or uninstall software using an MSI
package Windows AWS-InstallPowerShellModule Install PowerShell modules Windows
AWS-ConfigureCloudWatch Configure Amazon CloudWatch Logs to monitor
applications and systems Windows The commands or scripts specified in SSM
documents run with administrative privilege on your instances because the
Amazon SSM agent runs as root on Linux and the EC2Config service runs in the
Local System account on Windows. If a user has permission to execute any of the
pre-defined SSM documents (any document that begins with AWS-*) then that user
also has administrator access to the instance. Delegate access to SSM and Run
Command judiciously. This becomes extremely important if you create your own
SSM documents. Amazon Web Services does not provide guidance about how to
create secure SSM documents. You create SSM documents and delegate access to
Run Command at your own risk. As a security best practice, we recommend that
you assign access to "AWS-*" documents, especially the AWS-RunShellScript
document on Linux and the AWS-RunPowerShellScript document on Windows, to
trusted administrators only. You can create SSM documents for specific tasks
and delegate access to non-administrators.

The types from this library are intended to be used with
<http://hackage.haskell.org/package/amazonka amazonka>, which provides
mechanisms for specifying AuthN/AuthZ information and sending requests.

Use of lenses is required for constructing and manipulating types.
This is due to the amount of nesting of AWS types and transparency regarding
de/serialisation into more palatable Haskell values. The provided lenses should
be compatible with any of the major lens libraries such as
<http://hackage.haskell.org/package/lens lens> or
<http://hackage.haskell.org/package/lens-family-core lens-family-core>.

See "Network.AWS.SSM" or <https://aws.amazon.com/documentation/ the AWS
Documentation> to get started.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%defattr(-,root,root,-)
%doc LICENSE

%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%doc README.md

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.4.3 revision 0 with cabal2obs.
